aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--os/hal/include/pwm.h8
-rw-r--r--readme.txt1
2 files changed, 5 insertions, 4 deletions
diff --git a/readme.txt b/readme.txt
index 9547ba4b9..7a56d3b78 100644
--- a/readme.txt
+++ b/readme.txt
@@ -89,6 +89,7 @@
*****************************************************************************
*** 2.5.2 ***
+- FIX: Fixed wrong macro in PWM driver (bug #407)(backported to 2.4.4).
- FIX: Fixed USB driver possible deadlock under certain configurations (bug
#406)(backported to 2.4.4).
- FIX: Fixed USB driver cannot be stopped (bug #405)(backported to 2.4.4).
diff --git a/os/hal/include/pwm.h b/os/hal/include/pwm.h
index a735cfbc2..e943df382 100644
--- a/os/hal/include/pwm.h
+++ b/os/hal/include/pwm.h
@@ -169,13 +169,13 @@ typedef void (*pwmcallback_t)(PWMDriver *pwmp);
* guaranteed.
*
* @param[in] pwmp pointer to a @p PWMDriver object
* @param[in] period new cycle time in ticks
*
* @iclass
*/
-#define pwmChangePeriodI(pwmp, period) { \
- (pwmp)->period = (period); \
- pwm_lld_change_period(pwmp, period); \
+#define pwmChangePeriodI(pwmp, value) { \
+ (pwmp)->period = (value); \
+ pwm_lld_change_period(pwmp, value); \
}
/**
@@ -169,13 +169,13 @@ typedef void (*pwmcallback_t)(PWMDriver *pwmp);
*
* @param[in] pwmp pointer to a @p PWMDriver object
- * @param[in] period new cycle time in ticks
+ * @param[in] value new cycle time in ticks
*
* @iclass